pub enum PutRequestSpecific {
AnnouncePeer(AnnouncePeerRequestArguments),
AnnounceSignedPeer(AnnounceSignedPeerRequestArguments),
PutImmutable(PutImmutableRequestArguments),
PutMutable(PutMutableRequestArguments),
}Expand description
The kind of storage request, with operation-specific arguments.
This is the parameter passed to Dht::put for low-level
access. The high-level wrappers (Dht::put_immutable,
Dht::put_mutable,
Dht::announce_peer) construct one of these
internally.
Variants
AnnouncePeer(AnnouncePeerRequestArguments)
Announce that the sender is a peer for an info hash (BEP_0005).
AnnounceSignedPeer(AnnounceSignedPeerRequestArguments)
Announce a signed peer for an info hash (proposed signed-peers BEP).
PutImmutable(PutImmutableRequestArguments)
Store an immutable value, addressed by its sha1 hash (BEP_0044).
PutMutable(PutMutableRequestArguments)
Store a mutable value, addressed by an ed25519 public key (and optional salt) (BEP_0044).
Implementations