pub enum ConcurrencyError {
NotMostRecent,
CasFailed,
}Expand description
PutQuery for crate::MutableItem errors
Variants
NotMostRecent
The crate::MutableItem::seq is less than or equal the sequence from another signed item.
Try reading most recent mutable item before writing again.
CasFailed
The CAS condition does not match the seq of the most recent known signed item.