PutQueryError

Enum PutQueryError 

pub enum PutQueryError {
    NoClosestNodes,
    ErrorResponse(ErrorSpecific),
    Timeout,
    Shutdown,
}
Common PutQuery errors

Variants



NoClosestNodes

Failed to find any nodes close, usually means dht node failed to bootstrap, so the routing table is empty. Check the machine’s access to UDP socket, or find better bootstrapping nodes.



ErrorResponse(ErrorSpecific)

Either Put Query failed to store at any nodes, and most nodes responded with a non 301 nor 302 errors.

Either way; contains the most common error response.



Timeout

PutQuery timed out with no responses neither success or errors



Shutdown

The DHT actor task has shut down.