pub struct RequestSpecific {
pub requester_id: Id,
pub request_type: RequestTypeSpecific,
}Expand description
An incoming KRPC request, as observed by the local node.
Mostly useful as the input to a custom RequestFilter
when the node is running in server mode.
Fields
requester_id: IdThe Id claimed by the node sending the request.
request_type: RequestTypeSpecificThe body of the request, indicating which operation the sender wants performed.